@@ -354,7 +354,7 @@ class Base(Controller):
         help='Operations on CLI hist',
         arguments=[
             (['-s'],{
-                "help" : "To show the full command if too long to fit in terminal",
+                "help" : "Which lines to save separated by commas",
                 "action" : "store"
             }),
             (['-n'],{
@@ -387,14 +387,14 @@ class Base(Controller):
             n_lines = int(self.app.pargs.n or 20)
             lines_to_save = [int(x) for x in str(self.app.pargs.s).split(',')]
             snippet_name = self.app.pargs.__dict__.get('a') or self.app.pargs.__dict__.get('alias') or str(uuid.uuid4())
-            print(f'Saving {n_lines} lines from history to snippet {snippet_name}')
+            print(f'Saving {lines_to_save} lines from history to snippet {snippet_name}')
             
             hist_save(lines_to_save, snippet_name, n_lines=n_lines)
 
     @ex(
         help='Operations with snippets',
         arguments=[
-            (['n'],{
+            (['-n','--n_lines'],{
                 "help" : "Which snippet to run/create. Using commas to seperate ids"
                 "e.g. `dt run 13,23`",
                 "action" : "store"
@@ -414,27 +414,22 @@ class Base(Controller):
                 # TODO: figure out if bool
                 "action" : "store"   
             }),
-            (['--ls'],{
-                "help" : "Whether to list all snippets at different levels (0,1,2)",
+            (['-a','--alias'],{
+                "help": "Name of the alias to run",
                 "action" : "store"
             })
         ]
     )
     def run(self):
-        is_save = self.app.pargs.save or False
-        is_ls = self.app.pargs.ls or False
+        is_alias = self.app.pargs.__dict__.get('a') or self.app.pargs.__dict__.get('alias') or False
         
-        if not is_save:
-            from ..ext.run import run_command
-            n_lines = [int(x) for x in str(self.app.pargs.n).split(',')]
-            run_command(n_lines)
-        if is_ls:
-            from ..ext.run import list_snippets
-            list_snippets(int(self.app.pargs.ls))
+        if is_alias:
+            from ..ext.run import run_command_from_alias
+            run_command_from_alias(is_alias)
         else:
-            from ..ext.run import save_command
-            n_lines = [int(x) for x in str(self.app.pargs.n).split(',')]
-            save_command(n_lines)
+            from ..ext.run import run_command
+            n_lines = [int(x) for x in str(self.app.pargs.n_lines).split(',')]
+            run_command(n_lines)
             
     @ex(
         help='Operations with s3 bucket creationlabs-raw-data',
@@ -513,8 +508,8 @@ class Base(Controller):
     )
     def ssh(self):
         from ..ext.sshconf import read_ssh_config
-        ssh_config_path = os.path.expanduser('~/.ssh/config')
         from ..ext.sshconf import print_ls
+        ssh_config_path = os.path.expanduser('~/.ssh/config')
 
         if self.app.pargs.action=='set':
             ssh_config_obj = read_ssh_config(ssh_config_path)
@@ -590,7 +585,7 @@ class Base(Controller):
         # TODO: setup Data-toolkit specific config
         # shows config
         
-        if self.app.pargs.action=='show':
+        if self.app.pargs.action=='show' or self.app.pargs.action=='ls':
             from ..ext.config import show_config
             show_config()
 
@@ -605,7 +600,7 @@ class Base(Controller):
             from ..ext.tracking import initialize
             initialize(overwrite=True)
 
-        elif self.app.pargs.action not in ['set','loc', 'show']:
+        elif self.app.pargs.action not in ['set','loc', 'show','ls']:
             raise NotImplementedError("Try one of {show, set, loc}")
 
 
