@@ -1,6 +1,8 @@
 from ..ext.hist import hist_tail
 import os
 import json
+import pandas as pd
+import subprocess
 
 def get_command(n_lines: list):
     # TODO: propagate that last line in n_lines is the # of lines used
@@ -13,6 +15,20 @@ def get_command(n_lines: list):
         
     return exec_line
     
+def run_command_from_alias(alias: str):
+    from dt.ext.config import load_config
+    config = load_config()['snippets']
+    df = pd.DataFrame(config)
+    df.columns = ['Name','Time','Command']
+    
+    cmd_to_run = df[df['Name'] == alias]['Command'].values[0]
+    cmd_to_run = " && ".join(cmd_to_run)
+    
+    # TODO: maybe replace with this fix for source
+    # https://stackoverflow.com/questions/7040592/calling-the-source-command-from-subprocess-popen
+    print(f"Running {cmd_to_run}")
+    subprocess.Popen(cmd_to_run, shell=True)
+    
 def run_command(n_lines: list):
     exec_line = get_command(n_lines)
     print(f"Running {exec_line[:-4]}")
